@@ -28,8 +28,6 @@
 #include <string.h>
 #endif
 
-#include <libxfce4ui/libxfce4ui.h>
-
 #include "thunar/thunar-abstract-dialog.h"
 #include "thunar/thunar-action-manager.h"
 #include "thunar/thunar-application.h"
@@ -46,6 +44,8 @@
 #include "thunar/thunar-renamer-progress.h"
 #include "thunar/thunar-util.h"
 
+#include <libxfce4ui/libxfce4ui.h>
+
 
 
 /* Property identifiers */
@@ -75,80 +75,112 @@ typedef enum
 
 
 
-static void        thunar_renamer_dialog_dispose               (GObject                  *object);
-static void        thunar_renamer_dialog_finalize              (GObject                  *object);
-static void        thunar_renamer_dialog_get_property          (GObject                  *object,
-                                                                guint                     prop_id,
-                                                                GValue                   *value,
-                                                                GParamSpec               *pspec);
-static void        thunar_renamer_dialog_set_property          (GObject                  *object,
-                                                                guint                     prop_id,
-                                                                const GValue             *value,
-                                                                GParamSpec               *pspec);
-static void        thunar_renamer_dialog_realize               (GtkWidget                *widget);
-static void        thunar_renamer_dialog_unrealize             (GtkWidget                *widget);
-static void        thunar_renamer_dialog_response              (GtkDialog                *dialog,
-                                                                gint                      response);
-static void        thunar_renamer_dialog_context_menu          (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_help                  (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_save                  (ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_action_add_files      (ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_action_remove_files   (ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_action_clear          (ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_action_about          (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_name_column_clicked   (GtkTreeViewColumn        *column,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_button_press_event    (GtkWidget                *tree_view,
-                                                                GdkEventButton           *event,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_drag_data_received    (GtkWidget                *tree_view,
-                                                                GdkDragContext           *context,
-                                                                gint                      x,
-                                                                gint                      y,
-                                                                GtkSelectionData         *selection_data,
-                                                                guint                     info,
-                                                                guint                     timestamp,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_drag_leave            (GtkWidget                *tree_view,
-                                                                GdkDragContext           *context,
-                                                                guint                     timestamp,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_drag_motion           (GtkWidget                *tree_view,
-                                                                GdkDragContext           *context,
-                                                                gint                      x,
-                                                                gint                      y,
-                                                                guint                     timestamp,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_drag_drop             (GtkWidget                *tree_view,
-                                                                GdkDragContext           *context,
-                                                                gint                      x,
-                                                                gint                      y,
-                                                                guint                     timestamp,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_notify_page           (GtkNotebook              *notebook,
-                                                                GParamSpec               *pspec,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_popup_menu            (GtkWidget                *tree_view,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_row_activated         (GtkTreeView              *tree_view,
-                                                                GtkTreePath              *path,
-                                                                GtkTreeViewColumn        *column,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_selection_changed     (GtkTreeSelection         *selection,
-                                                                ThunarRenamerDialog      *renamer_dialog);
-static ThunarFile *thunar_renamer_dialog_get_current_directory (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_set_current_directory (ThunarRenamerDialog      *renamer_dialog,
-                                                                ThunarFile               *current_directory);
-static GList      *thunar_renamer_dialog_get_selected_files    (ThunarRenamerDialog      *renamer_dialog);
-static gboolean    thunar_renamer_dialog_get_standalone        (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_set_standalone        (ThunarRenamerDialog      *renamer_dialog,
-                                                                gboolean                  fixed);
-static GtkWidget  *thunar_renamer_dialog_append_menu_item      (ThunarRenamerDialog      *renamer_dialog,
-                                                                GtkMenuShell             *menu,
-                                                                ThunarRenamerAction       action);
-static gboolean    thunar_renamer_configure_event              (GtkWidget                *widget,
-                                                                GdkEventConfigure        *event);
-static void        thunar_renamer_save_geometry_timer_destroy  (gpointer                  user_data);                                                                
+static void
+thunar_renamer_dialog_dispose (GObject *object);
+static void
+thunar_renamer_dialog_finalize (GObject *object);
+static void
+thunar_renamer_dialog_get_property (GObject    *object,
+                                    guint       prop_id,
+                                    GValue     *value,
+                                    GParamSpec *pspec);
+static void
+thunar_renamer_dialog_set_property (GObject      *object,
+                                    guint         prop_id,
+                                    const GValue *value,
+                                    GParamSpec   *pspec);
+static void
+thunar_renamer_dialog_realize (GtkWidget *widget);
+static void
+thunar_renamer_dialog_unrealize (GtkWidget *widget);
+static void
+thunar_renamer_dialog_response (GtkDialog *dialog,
+                                gint       response);
+static void
+thunar_renamer_dialog_context_menu (ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_help (ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_save (ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_action_add_files (ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_action_remove_files (ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_action_clear (ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_action_about (ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_name_column_clicked (GtkTreeViewColumn   *column,
+                                           ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_button_press_event (GtkWidget           *tree_view,
+                                          GdkEventButton      *event,
+                                          ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_drag_data_received (GtkWidget           *tree_view,
+                                          GdkDragContext      *context,
+                                          gint                 x,
+                                          gint                 y,
+                                          GtkSelectionData    *selection_data,
+                                          guint                info,
+                                          guint                timestamp,
+                                          ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_drag_leave (GtkWidget           *tree_view,
+                                  GdkDragContext      *context,
+                                  guint                timestamp,
+                                  ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_drag_motion (GtkWidget           *tree_view,
+                                   GdkDragContext      *context,
+                                   gint                 x,
+                                   gint                 y,
+                                   guint                timestamp,
+                                   ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_drag_drop (GtkWidget           *tree_view,
+                                 GdkDragContext      *context,
+                                 gint                 x,
+                                 gint                 y,
+                                 guint                timestamp,
+                                 ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_notify_page (GtkNotebook         *notebook,
+                                   GParamSpec          *pspec,
+                                   ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_popup_menu (GtkWidget           *tree_view,
+                                  ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_row_activated (GtkTreeView         *tree_view,
+                                     GtkTreePath         *path,
+                                     GtkTreeViewColumn   *column,
+                                     ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_selection_changed (GtkTreeSelection    *selection,
+                                         ThunarRenamerDialog *renamer_dialog);
+static ThunarFile *
+thunar_renamer_dialog_get_current_directory (ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_set_current_directory (ThunarRenamerDialog *renamer_dialog,
+                                             ThunarFile          *current_directory);
+static GList *
+thunar_renamer_dialog_get_selected_files (ThunarRenamerDialog *renamer_dialog);
+static gboolean
+thunar_renamer_dialog_get_standalone (ThunarRenamerDialog *renamer_dialog);
+static void
+thunar_renamer_dialog_set_standalone (ThunarRenamerDialog *renamer_dialog,
+                                      gboolean             fixed);
+static GtkWidget *
+thunar_renamer_dialog_append_menu_item (ThunarRenamerDialog *renamer_dialog,
+                                        GtkMenuShell        *menu,
+                                        ThunarRenamerAction  action);
+static gboolean
+thunar_renamer_configure_event (GtkWidget         *widget,
+                                GdkEventConfigure *event);
+static void
+thunar_renamer_save_geometry_timer_destroy (gpointer user_data);
 
 
 
@@ -162,39 +194,40 @@ struct _ThunarRenamerDialog
   ThunarAbstractDialog __parent__;
 
   /* need to grab a reference on the icon factory for the standalone version */
-  ThunarIconFactory   *icon_factory;
+  ThunarIconFactory *icon_factory;
 
-  ThunarRenamerModel  *model;
+  ThunarRenamerModel *model;
 
   ThunarActionManager *action_mgr;
 
-  GtkWidget           *close_button;
+  GtkWidget *close_button;
 
-  GtkWidget           *tree_view;
-  GtkWidget           *progress;
+  GtkWidget *tree_view;
+  GtkWidget *progress;
 
-  GtkWidget           *mode_combo;
+  GtkWidget *mode_combo;
 
-  GtkTreeViewColumn   *name_column;
+  GtkTreeViewColumn *name_column;
 
   /* the current directory used for the "Add Files" dialog */
-  ThunarFile          *current_directory;
+  ThunarFile *current_directory;
 
   /* #GList of currently selected #ThunarFile<!---->s */
-  GList               *selected_files;
+  GList *selected_files;
 
   /* whether the dialog should act like a standalone application */
-  gboolean             standalone;
+  gboolean standalone;
 
   /* TRUE while drop highlighting */
-  gboolean             drag_highlighted;
-  
+  gboolean drag_highlighted;
+
   /* support to remember window geometry */
-  guint                save_geometry_timer_id;
+  guint save_geometry_timer_id;
 };
 
 
 
+/* clang-format off */
 static XfceGtkActionEntry thunar_renamer_action_entries[] =
 {
     { THUNAR_RENAMER_ACTION_ADD_FILES,    "<Actions>/ThunarRenamerDialog/add-files",    "", XFCE_GTK_IMAGE_MENU_ITEM, N_ ("_Add Files..."), N_ ("Include additional files in the list of files to be renamed"), "list-add",    G_CALLBACK (thunar_renamer_dialog_action_add_files),   },
@@ -202,12 +235,12 @@ static XfceGtkActionEntry thunar_renamer_action_entries[] =
     { THUNAR_RENAMER_ACTION_CLEAR,        "",                                           "", XFCE_GTK_IMAGE_MENU_ITEM, N_ ("Clear"),         N_ ("Clear the file list below"),                                   "edit-clear",  G_CALLBACK (thunar_renamer_dialog_action_clear),       },
     { THUNAR_RENAMER_ACTION_ABOUT,        "",                                           "", XFCE_GTK_IMAGE_MENU_ITEM, N_ ("_About"),        N_ ("Display information about Thunar Bulk Rename"),                "help-about",  G_CALLBACK (thunar_renamer_dialog_action_about),       },
 };
+/* clang-format on */
 
-#define get_action_entry(id) xfce_gtk_get_action_entry_by_id(thunar_renamer_action_entries,G_N_ELEMENTS(thunar_renamer_action_entries),id)
+#define get_action_entry(id) xfce_gtk_get_action_entry_by_id (thunar_renamer_action_entries, G_N_ELEMENTS (thunar_renamer_action_entries), id)
 
 /* Target types for dropping to the tree view */
-static const GtkTargetEntry drop_targets[] =
-{
+static const GtkTargetEntry drop_targets[] = {
   { "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, TARGET_GTK_TREE_MODEL_ROW },
   { "text/uri-list", 0, TARGET_TEXT_URI_LIST }
 };
@@ -369,13 +402,13 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
                 "last-renamer-dialog-height", &last_dialog_height,
                 "last-renamer-dialog-maximized", &last_dialog_maximized,
                 NULL);
-  g_object_unref(preferences);
+  g_object_unref (preferences);
   gtk_window_set_default_size (GTK_WINDOW (renamer_dialog), last_dialog_width, last_dialog_height);
-  
+
   /* restore the maxized state of the dialog */
   if (G_UNLIKELY (last_dialog_maximized))
     gtk_window_maximize (GTK_WINDOW (renamer_dialog));
-  
+
   gtk_window_set_title (GTK_WINDOW (renamer_dialog), _("Rename Multiple Files"));
 
   /* add the "Close" button */
@@ -385,7 +418,7 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
   /* add the "Rename" button */
   button = gtk_dialog_add_button (GTK_DIALOG (renamer_dialog), _("_Rename"), GTK_RESPONSE_APPLY);
   g_object_bind_property (G_OBJECT (renamer_dialog->model), "can-rename",
-                          G_OBJECT (button),                "sensitive",
+                          G_OBJECT (button), "sensitive",
                           G_BINDING_SYNC_CREATE);
   gtk_dialog_set_default_response (GTK_DIALOG (renamer_dialog), GTK_RESPONSE_APPLY);
   gtk_widget_set_tooltip_text (button, _("Rename items listed above, keep this window open."));
@@ -854,31 +887,31 @@ thunar_renamer_dialog_response (GtkDialog *dialog,
  *
  * Return value: (transfer none): The added #GtkMenuItem
  **/
-static GtkWidget*
+static GtkWidget *
 thunar_renamer_dialog_append_menu_item (ThunarRenamerDialog *renamer_dialog,
                                         GtkMenuShell        *menu,
                                         ThunarRenamerAction  action)
 {
-  gchar                      *label_text;
-  gchar                      *tooltip_text;
-  const XfceGtkActionEntry   *action_entry = get_action_entry (action);
-  GtkWidget                  *item;
+  gchar                    *label_text;
+  gchar                    *tooltip_text;
+  const XfceGtkActionEntry *action_entry = get_action_entry (action);
+  GtkWidget                *item;
 
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), NULL);
   _thunar_return_val_if_fail (action_entry != NULL, NULL);
 
   switch (action)
     {
-      case THUNAR_RENAMER_ACTION_REMOVE_FILES:
-        label_text = ngettext ("Remove File", "Remove Files", g_list_length (renamer_dialog->selected_files));
-        tooltip_text = ngettext ("Remove the selected file from the list of files to be renamed",
-                                 "Remove the selected files from the list of files to be renamed", g_list_length (renamer_dialog->selected_files));
-        item = xfce_gtk_image_menu_item_new_from_icon_name (label_text, tooltip_text, action_entry->accel_path, action_entry->callback,
-                                                            G_OBJECT (renamer_dialog), action_entry->menu_item_icon_name, GTK_MENU_SHELL (menu) );
-        gtk_widget_set_sensitive (item, renamer_dialog->selected_files != NULL);
-        return item;
-      default:
-        return xfce_gtk_menu_item_new_from_action_entry (action_entry, G_OBJECT (renamer_dialog), menu);
+    case THUNAR_RENAMER_ACTION_REMOVE_FILES:
+      label_text = ngettext ("Remove File", "Remove Files", g_list_length (renamer_dialog->selected_files));
+      tooltip_text = ngettext ("Remove the selected file from the list of files to be renamed",
+                               "Remove the selected files from the list of files to be renamed", g_list_length (renamer_dialog->selected_files));
+      item = xfce_gtk_image_menu_item_new_from_icon_name (label_text, tooltip_text, action_entry->accel_path, action_entry->callback,
+                                                          G_OBJECT (renamer_dialog), action_entry->menu_item_icon_name, GTK_MENU_SHELL (menu));
+      gtk_widget_set_sensitive (item, renamer_dialog->selected_files != NULL);
+      return item;
+    default:
+      return xfce_gtk_menu_item_new_from_action_entry (action_entry, G_OBJECT (renamer_dialog), menu);
     }
   return NULL;
 }
@@ -899,9 +932,9 @@ thunar_renamer_dialog_context_menu (ThunarRenamerDialog *renamer_dialog)
   g_object_ref (G_OBJECT (renamer_dialog));
 
   menu = g_object_new (THUNAR_TYPE_MENU, "menu-type", THUNAR_MENU_TYPE_CONTEXT_RENAMER,
-                                         "action_mgr", renamer_dialog->action_mgr,
-                                         "tab-support-disabled", TRUE,
-                                         "change_directory-support-disabled", TRUE, NULL);
+                       "action_mgr", renamer_dialog->action_mgr,
+                       "tab-support-disabled", TRUE,
+                       "change_directory-support-disabled", TRUE, NULL);
   thunar_menu_add_sections (menu, THUNAR_MENU_SECTION_OPEN | THUNAR_MENU_SECTION_SENDTO);
 
   /* determine the active renamer */
@@ -912,8 +945,8 @@ thunar_renamer_dialog_context_menu (ThunarRenamerDialog *renamer_dialog)
       items = thunarx_renamer_get_menu_items (renamer, GTK_WINDOW (renamer_dialog), renamer_dialog->selected_files);
       if (items != NULL)
         {
-          for(lp = items; lp != NULL; lp = lp->next)
-              thunar_gtk_menu_thunarx_menu_item_new (lp->data, GTK_MENU_SHELL (menu));
+          for (lp = items; lp != NULL; lp = lp->next)
+            thunar_gtk_menu_thunarx_menu_item_new (lp->data, GTK_MENU_SHELL (menu));
           g_list_free (items);
           xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
         }
@@ -1071,8 +1104,8 @@ thunar_renamer_dialog_action_add_files (ThunarRenamerDialog *renamer_dialog)
   chooser = gtk_file_chooser_dialog_new (_("Select files to rename"),
                                          GTK_WINDOW (renamer_dialog),
                                          GTK_FILE_CHOOSER_ACTION_OPEN,
-                                         _("_Cancel"), GTK_RESPONSE_CANCEL,
-                                         _("_Open"), GTK_RESPONSE_ACCEPT,
+                                           _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                             _("_Open"), GTK_RESPONSE_ACCEPT,
                                          NULL);
   gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (chooser), TRUE);
   gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (chooser), TRUE);
@@ -1230,8 +1263,7 @@ thunar_renamer_dialog_action_about (ThunarRenamerDialog *renamer_dialog)
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), FALSE);
 
   /* just popup the about dialog */
-  thunar_dialogs_show_about (GTK_WINDOW (renamer_dialog), _("Bulk Rename"),
-                             _("Thunar Bulk Rename is a powerful and extensible\n"
+  thunar_dialogs_show_about (GTK_WINDOW (renamer_dialog), _("Bulk Rename"), _("Thunar Bulk Rename is a powerful and extensible\n"
                                "tool to rename multiple files at once."));
 
   /* required in case of shortcut activation, in order to signal that the accel key got handled */
@@ -1336,13 +1368,13 @@ thunar_renamer_dialog_drag_data_received (GtkWidget           *tree_view,
                                           guint                timestamp,
                                           ThunarRenamerDialog *renamer_dialog)
 {
-  ThunarFile              *file;
-  GList                   *file_list;
-  GList                   *lp;
-  GtkTreeModel            *model;
-  GtkTreePath             *path;
-  GtkTreeViewDropPosition  drop_pos;
-  gint                     position = -1;
+  ThunarFile             *file;
+  GList                  *file_list;
+  GList                  *lp;
+  GtkTreeModel           *model;
+  GtkTreePath            *path;
+  GtkTreeViewDropPosition drop_pos;
+  gint                    position = -1;
 
   _thunar_return_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog));
   _thunar_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
@@ -1440,12 +1472,12 @@ thunar_renamer_dialog_drag_motion (GtkWidget           *tree_view,
                                    guint                timestamp,
                                    ThunarRenamerDialog *renamer_dialog)
 {
-  GdkAtom                  target;
-  GtkTreeViewDropPosition  position;
-  GtkTreePath             *path;
-  GdkDragAction            action;
-  GtkTreeModel            *model;
-  gint                     n_rows;
+  GdkAtom                 target;
+  GtkTreeViewDropPosition position;
+  GtkTreePath            *path;
+  GdkDragAction           action;
+  GtkTreeModel           *model;
+  gint                    n_rows;
 
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), FALSE);
   _thunar_return_val_if_fail (GTK_IS_TREE_VIEW (tree_view), FALSE);
@@ -1528,13 +1560,13 @@ thunar_renamer_dialog_drag_drop (GtkWidget           *tree_view,
                                  guint                timestamp,
                                  ThunarRenamerDialog *renamer_dialog)
 {
-  GdkAtom                  target;
-  GtkTreeSelection        *selection;
-  GtkTreePath             *dst_path;
-  GtkTreeModel            *model;
-  GtkTreeViewDropPosition  drop_pos;
-  gint                     position = -1;
-  GList                   *rows;
+  GdkAtom                 target;
+  GtkTreeSelection       *selection;
+  GtkTreePath            *dst_path;
+  GtkTreeModel           *model;
+  GtkTreeViewDropPosition drop_pos;
+  gint                    position = -1;
+  GList                  *rows;
 
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), FALSE);
   _thunar_return_val_if_fail (GTK_IS_TREE_VIEW (tree_view), FALSE);
@@ -1696,7 +1728,7 @@ thunar_renamer_dialog_selection_changed (GtkTreeSelection    *selection,
  *
  * Return value: the current directory for @renamer_dialog.
  **/
-static ThunarFile*
+static ThunarFile *
 thunar_renamer_dialog_get_current_directory (ThunarRenamerDialog *renamer_dialog)
 {
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), NULL);
@@ -1752,7 +1784,7 @@ thunar_renamer_dialog_set_current_directory (ThunarRenamerDialog *renamer_dialog
  *
  * Return value: the list of currently selected files.
  **/
-static GList*
+static GList *
 thunar_renamer_dialog_get_selected_files (ThunarRenamerDialog *renamer_dialog)
 {
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), NULL);
