@@ -1,7 +1,7 @@
 #include <gio/gio.h>
 
 #if defined(__ELF__) && (__GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
-#define SECTION __attribute__ ((section (".gresource.thunar"), aligned (8)))
+#define SECTION __attribute__ ((section (".gresource.thunar"), aligned (sizeof (void *) > 8 ? sizeof (void *) : 8)))
 #else
 #define SECTION
 #endif
@@ -49,7 +49,8 @@ static const SECTION union
 static GStaticResource static_resource = { thunar_resource_data.data, sizeof (thunar_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };
 
 G_MODULE_EXPORT
-GResource *thunar_get_resource (void);
+GResource *
+thunar_get_resource (void);
 GResource *
 thunar_get_resource (void)
 {
@@ -109,10 +110,9 @@ thunar_get_resource (void)
 #define G_HAS_CONSTRUCTORS 1
 
 #define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__ ((constructor)) _func (void);
-#define G_DEFINE_DESTRUCTOR(_func)  static void __attribute__ ((destructor)) _func (void);
+#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__ ((destructor)) _func (void);
 
-#elif defined(_MSC_VER) && (_MSC_VER >= 1500)
-/* Visual studio 2008 and later has _Pragma */
+#elif defined(_MSC_VER)
 
 /*
  * Only try to include gslist.h if not already included via glib.h,
@@ -147,61 +147,33 @@ thunar_get_resource (void)
 #endif
 
 #define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
-#define G_DEFINE_DESTRUCTOR(_func)  G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)
+#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)
 
-#define G_MSVC_CTOR(_func, _sym_prefix)                                  \
-  static void _func (void);                                              \
-  extern int (*_array##_func) (void);                                    \
-  int _func##_wrapper (void)                                             \
-  {                                                                      \
-    _func ();                                                            \
-    g_slist_find (NULL, _array##_func);                                  \
-    return 0;                                                            \
-  }                                                                      \
+#define G_MSVC_CTOR(_func, _sym_prefix) \
+  static void _func (void); \
+  extern int (*_array##_func) (void); \
+  int _func##_wrapper (void); \
+  int _func##_wrapper (void) \
+  { \
+    _func (); \
+    g_slist_find (NULL, _array##_func); \
+    return 0; \
+  } \
   __pragma (comment (linker, "/include:" _sym_prefix #_func "_wrapper")) \
-    __pragma (section (".CRT$XCU", read)) __declspec (allocate (".CRT$XCU")) int (*_array##_func) (void) = _func##_wrapper;
+  __pragma (section (".CRT$XCU", read)) __declspec (allocate (".CRT$XCU")) int (*_array##_func) (void) = _func##_wrapper;
 
-#define G_MSVC_DTOR(_func, _sym_prefix)                                      \
-  static void _func (void);                                                  \
-  extern int (*_array##_func) (void);                                        \
-  int _func##_constructor (void)                                             \
-  {                                                                          \
-    atexit (_func);                                                          \
-    g_slist_find (NULL, _array##_func);                                      \
-    return 0;                                                                \
-  }                                                                          \
+#define G_MSVC_DTOR(_func, _sym_prefix) \
+  static void _func (void); \
+  extern int (*_array##_func) (void); \
+  int _func##_constructor (void); \
+  int _func##_constructor (void) \
+  { \
+    atexit (_func); \
+    g_slist_find (NULL, _array##_func); \
+    return 0; \
+  } \
   __pragma (comment (linker, "/include:" _sym_prefix #_func "_constructor")) \
-    __pragma (section (".CRT$XCU", read)) __declspec (allocate (".CRT$XCU")) int (*_array##_func) (void) = _func##_constructor;
-
-#elif defined(_MSC_VER)
-
-#define G_HAS_CONSTRUCTORS                1
-
-/* Pre Visual studio 2008 must use #pragma section */
-#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
-#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA  1
-
-#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
-  section (".CRT$XCU", read)
-#define G_DEFINE_CONSTRUCTOR(_func)  \
-  static void _func (void);          \
-  static int  _func##_wrapper (void) \
-  {                                  \
-    _func ();                        \
-    return 0;                        \
-  }                                  \
-  __declspec (allocate (".CRT$XCU")) static int (*p) (void) = _func##_wrapper;
-
-#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
-  section (".CRT$XCU", read)
-#define G_DEFINE_DESTRUCTOR(_func)       \
-  static void _func (void);              \
-  static int  _func##_constructor (void) \
-  {                                      \
-    atexit (_func);                      \
-    return 0;                            \
-  }                                      \
-  __declspec (allocate (".CRT$XCU")) static int (*_array##_func) (void) = _func##_constructor;
+  __pragma (section (".CRT$XCU", read)) __declspec (allocate (".CRT$XCU")) int (*_array##_func) (void) = _func##_constructor;
 
 #elif defined(__SUNPRO_C)
 
@@ -212,7 +184,7 @@ thunar_get_resource (void)
 #define G_HAS_CONSTRUCTORS 1
 
 #define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
-#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA  1
+#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1
 
 #define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
   init (_func)
