@@ -27,16 +27,16 @@ G_BEGIN_DECLS;
 typedef struct _ThunarTreeModelClass ThunarTreeModelClass;
 typedef struct _ThunarTreeModel      ThunarTreeModel;
 
-typedef gboolean (* ThunarTreeModelVisibleFunc) (ThunarTreeModel *model,
-                                                 ThunarFile      *file,
-                                                 gpointer         data);
+typedef gboolean (*ThunarTreeModelVisibleFunc) (ThunarTreeModel *model,
+                                                ThunarFile      *file,
+                                                gpointer         data);
 
-#define THUNAR_TYPE_TREE_MODEL            (thunar_tree_model_get_type ())
-#define THUNAR_TREE_MODEL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_TREE_MODEL, ThunarTreeModel))
-#define THUNAR_TREE_MODEL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_TREE_MODEL, ThunarTreeModelClass))
-#define THUNAR_IS_TREE_MODEL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_TREE_MODEL))
+#define THUNAR_TYPE_TREE_MODEL (thunar_tree_model_get_type ())
+#define THUNAR_TREE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_TREE_MODEL, ThunarTreeModel))
+#define THUNAR_TREE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_TREE_MODEL, ThunarTreeModelClass))
+#define THUNAR_IS_TREE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_TREE_MODEL))
 #define THUNAR_IS_TREE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THUNAR_TYPE_TREE_MODEL))
-#define THUNAR_TREE_MODEL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_TREE_MODEL, ThunarTreeModelClass))
+#define THUNAR_TREE_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_TREE_MODEL, ThunarTreeModelClass))
 
 /**
  * ThunarTreeModelColumn:
@@ -57,19 +57,25 @@ typedef enum
   THUNAR_TREE_MODEL_N_COLUMNS,
 } ThunarTreeModelColumn;
 
-GType            thunar_tree_model_get_type           (void) G_GNUC_CONST;
+GType
+thunar_tree_model_get_type (void) G_GNUC_CONST;
 
-void             thunar_tree_model_set_visible_func   (ThunarTreeModel            *model,
-                                                       ThunarTreeModelVisibleFunc  func,
-                                                       gpointer                    data);
-void             thunar_tree_model_refilter           (ThunarTreeModel            *model);
+void
+thunar_tree_model_set_visible_func (ThunarTreeModel           *model,
+                                    ThunarTreeModelVisibleFunc func,
+                                    gpointer                   data);
+void
+thunar_tree_model_refilter (ThunarTreeModel *model);
 
-void             thunar_tree_model_cleanup            (ThunarTreeModel            *model);
-gboolean         thunar_tree_model_node_has_dummy     (ThunarTreeModel            *model,
-                                                       GNode                      *node);
-void             thunar_tree_model_add_child          (ThunarTreeModel            *model,
-                                                       GNode                      *node,
-                                                       ThunarFile                 *file);
+void
+thunar_tree_model_cleanup (ThunarTreeModel *model);
+gboolean
+thunar_tree_model_node_has_dummy (ThunarTreeModel *model,
+                                  GNode           *node);
+void
+thunar_tree_model_add_child (ThunarTreeModel *model,
+                             GNode           *node,
+                             ThunarFile      *file);
 
 G_END_DECLS;
 
