@@ -37,24 +37,34 @@ enum
 
 
 
-static void          thunar_tree_pane_component_init        (ThunarComponentIface *iface);
-static void          thunar_tree_pane_navigator_init        (ThunarNavigatorIface *iface);
-static void          thunar_tree_pane_side_pane_init        (ThunarSidePaneIface  *iface);
-static void          thunar_tree_pane_dispose               (GObject              *object);
-static void          thunar_tree_pane_get_property          (GObject              *object,
-                                                             guint                 prop_id,
-                                                             GValue               *value,
-                                                             GParamSpec           *pspec);
-static void          thunar_tree_pane_set_property          (GObject              *object,
-                                                             guint                 prop_id,
-                                                             const GValue         *value,
-                                                             GParamSpec           *pspec);
-static ThunarFile   *thunar_tree_pane_get_current_directory (ThunarNavigator      *navigator);
-static void          thunar_tree_pane_set_current_directory (ThunarNavigator      *navigator,
-                                                             ThunarFile           *current_directory);
-static gboolean      thunar_tree_pane_get_show_hidden       (ThunarSidePane       *side_pane);
-static void          thunar_tree_pane_set_show_hidden       (ThunarSidePane       *side_pane,
-                                                             gboolean              show_hidden);
+static void
+thunar_tree_pane_component_init (ThunarComponentIface *iface);
+static void
+thunar_tree_pane_navigator_init (ThunarNavigatorIface *iface);
+static void
+thunar_tree_pane_side_pane_init (ThunarSidePaneIface *iface);
+static void
+thunar_tree_pane_dispose (GObject *object);
+static void
+thunar_tree_pane_get_property (GObject    *object,
+                               guint       prop_id,
+                               GValue     *value,
+                               GParamSpec *pspec);
+static void
+thunar_tree_pane_set_property (GObject      *object,
+                               guint         prop_id,
+                               const GValue *value,
+                               GParamSpec   *pspec);
+static ThunarFile *
+thunar_tree_pane_get_current_directory (ThunarNavigator *navigator);
+static void
+thunar_tree_pane_set_current_directory (ThunarNavigator *navigator,
+                                        ThunarFile      *current_directory);
+static gboolean
+thunar_tree_pane_get_show_hidden (ThunarSidePane *side_pane);
+static void
+thunar_tree_pane_set_show_hidden (ThunarSidePane *side_pane,
+                                  gboolean        show_hidden);
 
 
 
@@ -220,7 +230,7 @@ thunar_tree_pane_set_property (GObject      *object,
 
 
 
-static ThunarFile*
+static ThunarFile *
 thunar_tree_pane_get_current_directory (ThunarNavigator *navigator)
 {
   return THUNAR_TREE_PANE (navigator)->current_directory;
@@ -277,5 +287,3 @@ thunar_tree_pane_set_show_hidden (ThunarSidePane *side_pane,
       g_object_notify (G_OBJECT (tree_pane), "show-hidden");
     }
 }
-
-
